@@ -1,4 +1,4 @@
-/* $Id: gdict-app.c,v 1.123 2005/02/01 21:54:42 vnoel Exp $ */
+/* $Id: gdict-app.c,v 1.124 2005/03/03 17:08:30 vnoel Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -623,7 +623,7 @@ static const gchar *search_type_ui =
 static GtkActionEntry menu_entries[] = {
 
   /* Top */
-  { "DictionaryMenu", NULL, "_Dictionary" },
+  { "DictionaryMenu", NULL, N_("_Dictionary") },
   { "EditMenu", NULL, "_Edit" },
   { "ViewMenu", NULL, "_View" },
   { "HelpMenu", NULL, "_Help" },
