@@ -1,4 +1,4 @@
-/* $Id: gdict-pref.c,v 1.27 2005/01/18 19:33:52 vnoel Exp $ */
+/* $Id: gdict-pref.c,v 1.27.2.1 2005/04/06 13:29:18 vnoel Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -23,7 +23,7 @@
 #include "gdict-pref.h"
 #include "gdict-applet.h"
 
-#define GCONF_PATH "/apps/gnome_dictionary/%s"
+#define GCONF_PATH "/apps/gnome-dictionary/%s"
 
 static GConfClient *gdict_client = NULL;
 
