@@ -1,16 +1,33 @@
-#include <config.h>
+/*  ----------------------------------------------------------------------
+
+    Copyright (C) 1998  Cesar Miquel  (miquel@df.uba.ar)
+
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+    ---------------------------------------------------------------------- */
+
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
+#include "actions.h"
 #include "logview.h"
 #include <string.h>
-#include <stdlib.h>
-#include <sys/types.h>
 #include <regex.h>
-#include <gnome.h>
 
 #define MAX_NUM_MATCHES     10
 #define DELIM               ":"
 
-void mon_edit_actions (GtkWidget *widget, gpointer data);
-
 static GList *copy_actions_db (GList *db);
 void free_actions_db (GList **db);
 void free_action (Action *action);
@@ -24,15 +41,9 @@ static void add_actions_entry_cb (GtkWidget *widget, gpointer data);
 static void edit_action_entry (Action *action);
 static void set_atk_relation (GtkWidget *label, GtkWidget *widget);
 
-int exec_action_in_db (Log *log, LogLine *line, GList *db);
-int read_actions_db (char *filename, GList **db);
 int write_actions_db (char *filename, GList *db);
 
-
-
 extern GList *actions_db;
-
-
 static GList *local_actions_db = NULL;
 
 GtkWidget *actions_dialog = NULL;
@@ -50,7 +61,7 @@ apply_actions (GtkWidget *w, gpointer data)
 	actions_db = local_actions_db;
 	local_actions_db = NULL;
 
-	fname = gnome_util_home_file ("gnome-system-log-actions.db");
+	fname = g_strdup_printf ("%s/.gnome2/gnome-system-log-actions.db", g_get_home_dir());
 	if (write_actions_db (fname, actions_db)) {
 		gtk_widget_destroy (actions_dialog);
 	}
@@ -478,17 +489,17 @@ exec_action_in_db (Log *log, LogLine *line, GList *db)
   /* If there is a non-null action execute it */
   if (cur_action != NULL)
    {
-     if ((pid = fork()) < 0)
+     GError *error = NULL;
+
+     if (!g_spawn_command_line_async(cur_action->action, &error) && error != NULL)
       {
-        return FALSE;
-      }
-     else if (pid == 0)
-      {
-        if (execlp(cur_action->action, cur_action->action, NULL) == -1)
-         {
-	   ShowErrMessage (_("Error while executing specified action"));
-	   exit(1);
-         }
+        gchar *err_msg;
+
+        err_msg = g_strdup_printf (_("Error while executing specified action: %s"), error->message);
+        ShowErrMessage (err_msg);
+
+        g_free (err_msg);
+        g_error_free(error);
       }
    }
 
